@@ -13,10 +13,10 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Path::Tiny;
 
-our $VERSION = 0.004;
+our $VERSION = 0.005;
 
 sub directory {
-    my ($self) = @_;
+    my ($self, $options) = @_;
 
     my $dir  = path('.')->absolute;
     my $home = path($ENV{HOME});
@@ -28,6 +28,9 @@ sub directory {
     if (length $dir_display > 20) {
         $dir_display = '...' . substr $dir_display, -20, 20;
     }
+    if ($options->{abreviate}) {
+        $dir_display =~ s{/([^/])[^/]+/}{/$1/}g;
+    }
 
     my $len = length $dir_display;
 
@@ -88,7 +91,7 @@ App::PS1::Plugin::Directory - Current directory information
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Directory version 0.004.
+This documentation refers to App::PS1::Plugin::Directory version 0.005.
 
 =head1 SYNOPSIS
 
